﻿import { MenuDataItem } from '@ant-design/pro-layout'

const routes: MenuDataItem[] = [
  {
    path: '/user',
    layout: false,
    routes: [
      {
        path: '/user',
        routes: [
          {
            name: 'login',
            path: '/user/login',
            component: './user/Login'
          }
        ]
      },
      {
        component: './404'
      }
    ]
  },
  {
    path: '/',
    redirect: '/project/management'
  },
  {
    path: '/project',
    name: 'project',
    icon: 'AppstoreOutlined',
    routes: [
      {
        path: '/project',
        redirect: '/project/management'
      },
      {
        path: '/project/management',
        name: 'management',
        access: 'authRouteFilter',
        hideChildrenInMenu: true,
        routes: [
          {
            path: '/project/management',
            redirect: '/project/management/list'
          },
          {
            path: '/project/management/list',
            name: 'management-list',
            access: 'authRouteFilter',
            component: './Project/Management/List'
          },
          {
            path: '/project/management/:id',
            name: 'management-detail',
            access: 'authRouteFilter',
            component: './Project/Management/Detail'
          }
        ]
      },
      {
        path: '/project/approval',
        name: 'approval',
        access: 'authRouteFilter',
        component: './Project/Approval'
      },
      {
        path: '/project/verification',
        name: 'verification',
        access: 'authRouteFilter',
        component: './Project/Verification'
      }
    ]
  },
  {
    path: 'institutions',
    name: 'institutions',
    icon: 'BankOutlined',
    routes: [
      {
        path: '/institutions',
        redirect: '/institutions/company'
      },
      {
        path: 'company',
        name: 'company',
        hideChildrenInMenu: true,
        routes: [
          {
            path: '/institutions/company',
            redirect: '/institutions/company/list'
          },
          {
            path: 'list',
            name: 'company-list',
            access: 'authRouteFilter',
            component: './Institutions/Company/List'
          },
          {
            path: ':id',
            name: 'company-detail',
            access: 'authRouteFilter',
            component: './Institutions/Company/Detail'
          }
        ]
      },
      {
        path: 'staff',
        name: 'staff',
        access: 'authRouteFilter',
        component: './Institutions/Staff'
      },
      {
        path: 'restrict',
        name: 'restrict',
        access: 'authRouteFilter',
        component: './Institutions/Restrict'
      }
    ]
  },
  {
    path: 'business',
    name: 'business',
    icon: 'Audit',
    routes: [
      {
        path: '/business',
        redirect: '/business/inventory'
      },
      {
        path: 'inventory',
        name: 'inventory',
        access: 'authRouteFilter',
        component: './Business/Inventory'
      },
      {
        path: 'process',
        name: 'process',
        access: 'authRouteFilter',
        component: './Business/Process'
      }
    ]
  },
  {
    path: '/schema',
    name: 'schema',
    icon: 'ControlOutlined',
    routes: [
      {
        path: 'base',
        name: 'base',
        access: 'authRouteFilter',
        icon: 'icon-schema',
        component: './Schema/Base/index.tsx'
      },
      {
        path: 'base/:id',
        name: 'baseDetail',
        access: 'authRouteFilter',
        component: './Schema/Base/detail.tsx',
        hideInMenu: true
      },
      {
        path: 'option',
        name: 'option',
        access: 'authRouteFilter',
        component: './Schema/Option'
      },
      {
        path: 'budget',
        name: 'budget',
        access: 'authRouteFilter',
        component: './Schema/Budget'
      },
      {
        path: 'budget/:id',
        name: 'budgetDetail',
        component: './Schema/Budget/detail',
        hideInMenu: true
      }
    ]
  },
  {
    path: 'permission',
    name: 'permission',
    icon: 'UserOutlined',
    routes: [
      {
        path: '/permission',
        redirect: '/permission/role'
      },
      {
        path: 'role',
        name: 'role',
        access: 'authRouteFilter',
        component: './Permission/Role'
      }
    ]
  },
  {
    path: 'system',
    name: 'system',
    icon: 'SettingOutlined',
    routes: [
      {
        path: '/system',
        redirect: '/system/admin'
      },
      // {
      //   path: 'setting',
      //   name: 'setting',
      //   component: './System/Setting'
      // },
      {
        path: 'admin',
        name: 'admin',
        access: 'authRouteFilter',
        component: './System/Admin'
      }
    ]
  },

  {
    component: './404'
  }
]

export default routes
