import { PageContainer } from '@ant-design/pro-layout'
import { useDispatch, connect } from 'umi'
import { message } from 'antd'
import React, { useState, useEffect } from 'react'
import LeftMenu from './components/LeftMenu'
import { createForm, onFieldReact } from '@formily/core'
import { createSchemaField } from '@formily/react'
import {
  FormItem,
  Input,
  Switch,
  Select,
  FormGrid,
  FormLayout,
  Form,
  Radio,
  Checkbox,
  NumberPicker,
  Password,
  DatePicker,
  TimePicker,
  TreeSelect,
  FormButtonGroup,
  Submit
} from '@formily/antd'
import { schema } from './schema'
import { queryOrganizationalMembersList } from '@/services/api/institution'
import { useRequest } from '@umijs/max'
import consts from '@/utils/consts'
import { queryApprovalAccountDetail, saveApprovalAccount } from '@/services/api/schema'

export enum LeftMenuEnum {
  BUDGET = '1'
}

export const menuOptions = [{ label: '预算业务审批', value: LeftMenuEnum.BUDGET }]

type iProcessProps = {
  activeKey: LeftMenuEnum
  approvalAccountDetail: API.ApprovalAccountDetail[]
}

let cacheKeys: string[] = []

const Process: React.FC = props => {
  const { institutionList } = props
  const dispatch = useDispatch()
  const [state, setState] = useState<iProcessProps>({
    activeKey: LeftMenuEnum.BUDGET,
    approvalAccountDetail: null
  })

  useRequest(queryApprovalAccountDetail, {
    onSuccess: (result: API.ApprovalAccountDetail) => {
      setState({
        ...state,
        approvalAccountDetail:
          result?.reduce((prev, curr) => {
            const obj = { ...prev }
            obj[curr.name] = {
              [`${curr.name}InstitutionID`]: curr.institutionID,
              [`${curr.name}AccountIDs`]: curr.accountIDs
            }
            return obj
          }, {}) || []
      })
    }
  })

  const renderTreeNodes = data =>
    data.map(item => {
      const newItem = { ...item }
      if (newItem.children) {
        newItem.disabled = true
        newItem.children = renderTreeNodes(newItem.children)
        return newItem
      }
      return newItem
    })

  useEffect(() => {
    if (!institutionList.length) {
      dispatch({
        type: 'business/queryInstitution',
        payload: { pageSize: 214000 }
      })
    }
    // tryApprovalAccountDetail()
  }, [])

  console.log('2')

  const form = createForm({
    initialValues: state.approvalAccountDetail,
    effects() {
      onFieldReact('receiver.receiverInstitutionID', async field => {
        if (!field.dataSource?.length) {
          // 将企事业列表直接赋予当前字段
          field.dataSource = institutionList?.items?.map(item => ({
            value: item.ID,
            label: item.name
          }))
          return
        }
        // 收件人企事业id
        const institutionID: undefined | string = field.value
        institutionID &&
          form.setFieldState('receiver.receiverAccountIDs', async field => {
            const { code = -1, data } = await queryOrganizationalMembersList({ institutionID })
            if (code === consts.RET_CODE.SUCCESS) {
              if (cacheKeys.some((key: string) => key.startsWith('receiver_'))) {
                // 说明当前企事业id已变，需要将当前field的value置空
                field.value = []
                cacheKeys = cacheKeys
                  .filter(item => item.startsWith('receiver_'))
                  .concat(`receiver_${institutionID}`)
              } else {
                cacheKeys = cacheKeys.concat(`receiver_${institutionID}`)
              }
              field.dataSource = renderTreeNodes(data)
            }
          })
      })
      onFieldReact('fgLeader.fgLeaderInstitutionID', async field => {
        if (!field.dataSource?.length) {
          field.dataSource = institutionList?.items?.map(item => ({
            value: item.ID,
            label: item.name
          }))
          return
        }
        const institutionID: undefined | string = field.value
        institutionID &&
          form.setFieldState('fgLeader.fgLeaderAccountIDs', async field => {
            const { code = -1, data } = await queryOrganizationalMembersList({ institutionID })
            if (code === consts.RET_CODE.SUCCESS) {
              if (cacheKeys.some((key: string) => key.startsWith('fgLeader_'))) {
                // 说明当前企事业id已变，需要将当前field的value置空
                field.value = []
                cacheKeys = cacheKeys
                  .filter(item => item.startsWith('fgLeader_'))
                  .concat(`fgLeader_${institutionID}`)
              } else {
                cacheKeys = cacheKeys.concat(`fgLeader_${institutionID}`)
              }

              field.dataSource = renderTreeNodes(data)
            }
          })
      })
      onFieldReact('zxLeader.zxLeaderInstitutionID', async field => {
        if (!field.dataSource?.length) {
          field.dataSource = institutionList?.items?.map(item => ({ value: item.ID, label: item.name }))
          return
        }
        const institutionID: undefined | string = field.value
        institutionID &&
          form.setFieldState('zxLeader.zxLeaderAccountIDs', async field => {
            const { code = -1, data } = await queryOrganizationalMembersList({ institutionID })
            if (code === consts.RET_CODE.SUCCESS) {
              field.dataSource = renderTreeNodes(data)
              if (cacheKeys.some((key: string) => key.startsWith('zxLeader_'))) {
                // 说明当前企事业id已变，需要将当前field的value置空
                field.value = []
                cacheKeys = cacheKeys
                  .filter(item => item.startsWith('zxLeader_'))
                  .concat(`zxLeader_${institutionID}`)
              } else {
                cacheKeys = cacheKeys.concat(`zxLeader_${institutionID}`)
              }
            }
          })
      })
      onFieldReact('post.postInstitutionID', async field => {
        if (!field.dataSource?.length) {
          field.dataSource = institutionList?.items?.map(item => ({ value: item.ID, label: item.name }))
          return
        }
        const institutionID: undefined | string = field.value
        institutionID &&
          form.setFieldState('post.postAccountIDs', async field => {
            const { code = -1, data } = await queryOrganizationalMembersList({ institutionID })
            if (code === consts.RET_CODE.SUCCESS) {
              if (cacheKeys.some((key: string) => key.startsWith('post_'))) {
                // 说明当前企事业id已变，需要将当前field的value置空
                field.value = []
                cacheKeys = cacheKeys.filter(item => item.startsWith('post_')).concat(`post_${institutionID}`)
              }
              cacheKeys = cacheKeys.concat(`post_${institutionID}`)
              field.dataSource = renderTreeNodes(data)
            }
          })
      })
      onFieldReact('archive.archiveInstitutionID', async field => {
        if (!field.dataSource?.length) {
          field.dataSource = institutionList?.items?.map(item => ({ value: item.ID, label: item.name }))
          return
        }
        const institutionID: undefined | string = field.value
        institutionID &&
          form.setFieldState('archive.archiveAccountIDs', async field => {
            const { code = -1, data } = await queryOrganizationalMembersList({ institutionID })
            if (code === consts.RET_CODE.SUCCESS) {
              if (cacheKeys.some((key: string) => key.startsWith('archive_'))) {
                // 说明当前企事业id已变，需要将当前field的value置空
                field.value = []
                cacheKeys = cacheKeys
                  .filter(item => item.startsWith('archive_'))
                  .concat(`archive_${institutionID}`)
              } else {
                cacheKeys = cacheKeys.concat(`archive_${institutionID}`)
              }
              field.dataSource = renderTreeNodes(data)
            }
          })
      })
    }
  })

  const SchemaField = createSchemaField({
    components: {
      FormLayout,
      FormItem,
      FormGrid,
      Input,
      Switch,
      Select,
      Radio,
      Checkbox,
      NumberPicker,
      Password,
      DatePicker,
      TimePicker,
      TreeSelect
    }
  })

  const onFinish = async (values: Record<string, any>) => {
    const keys = Object.keys(values)
    const params = keys.reduce((prev, curr) => {
      const obj = { ...prev, ...values[curr] }
      return obj
    }, {})
    const { code = -1 } = await saveApprovalAccount(params)
    if (code === consts.RET_CODE.SUCCESS) {
      message.success('编辑成功')
    }
  }

  return (
    <PageContainer title={false}>
      <div className="h-full w-full flex flex-row">
        <LeftMenu
          title="流程用户设置"
          options={menuOptions}
          value={state.activeKey}
          onChange={key => setState({ ...state, activeKey: key })}
        />
        <div className="w-6/7 ml-8 bg-white p-6 rounded-20px">
          <div className="flex flex-row mb-5 w-full text-xl">流程用户设置</div>
          <div className="max-w-800px">
            <div className="w-600px">
              <Form form={form} labelCol={8} wrapperCol={16}>
                <SchemaField schema={schema} />
                <FormButtonGroup.Sticky className="ml-100px">
                  <Submit onSubmit={onFinish}>提交</Submit>
                </FormButtonGroup.Sticky>
              </Form>
            </div>
          </div>
        </div>
      </div>
    </PageContainer>
  )
}

export default connect(({ business }) => ({
  institutionList: business.institutionList
}))(Process)
