import React from 'react'
import { Input as FormilyInput } from '@formily/antd'
import { createBehavior, createResource } from '@designable/core'
import { DnFC } from '@designable/react'
import { createFieldSchema } from '../Field'
import { AllSchemas } from '../../schemas'
import { AllLocales } from '../../locales'

export const Input: DnFC<React.ComponentProps<typeof FormilyInput>> = FormilyInput

Input.Behavior = createBehavior(
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'gcName',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '工程名称' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'gzAddress',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '工程地址' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'ministry',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '行业主管部门' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'institutionID',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '建设单位' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'reviewerMobile',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '报审人手机' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'reviewerMail',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '报审人邮箱' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'reviewerLandline',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '报审人座机' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'pMobile',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '项目联系手机' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'projectContactMobile',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '项目联系人手机' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'pMail',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '项目联系人邮箱' } }
  },
  {
    name: 'Input',
    extends: ['Field'],
    selector: node => node.props['name'] === 'projectContactLandline',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '项目联系人座机' } }
  },
  {
    name: 'Input.TextArea',
    extends: ['Field'],
    selector: node => node.props['name'] === 'reportingInstructions',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Input.TextArea)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Input['zh-CN'], title: '报审说明' } }
  }
)

Input.Resource = createResource(
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '工程名称(业务名称)',
          name: 'gcName',
          required: true,
          'x-decorator': 'FormItem',
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请输入'
          }
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '',
          name: 'bScaleUnit',
          'x-decorator': 'FormItem',
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请选择单位'
          }
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '工程地址',
          name: 'gzAddress',
          'x-decorator': 'FormItem',
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请输入'
          }
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '建设单位',
          name: 'institutionID',
          'x-decorator': 'FormItem',
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请输入'
          }
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '行业主管部门',
          name: 'ministry',
          'x-decorator': 'FormItem',
          required: true,
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请输入'
          }
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '报审人手机',
          name: 'reviewerMobile',
          required: true,
          'x-validator': 'phone',
          'x-decorator': 'FormItem',
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请输入'
          }
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '报审人邮箱',
          name: 'reviewerMail',
          required: true,
          'x-validator': 'email',
          'x-decorator': 'FormItem',
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请输入'
          }
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '联系座机',
          name: 'reviewerLandline',
          'x-validator': [
            {
              triggerType: 'onInput',
              message: '请输入正确的座机号',
              pattern: '^(?:(?:\\d{3}-)?\\d{8}|^(?:\\d{4}-)?\\d{7,8})(?:-\\d+)?$',
              whitespace: true
            }
          ],
          'x-decorator': 'FormItem',
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请输入'
          }
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '项目联系人手机',
          name: 'projectContactMobile',
          required: true,
          'x-validator': 'phone',
          'x-decorator': 'FormItem',
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请输入'
          }
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '项目联系人邮箱',
          name: 'pMail',
          'x-validator': 'email',
          required: true,
          'x-decorator': 'FormItem',
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请输入'
          }
        }
      }
    ]
  },
  {
    icon: 'InputSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '联系座机',
          name: 'projectContactLandline',
          'x-validator': [
            {
              triggerType: 'onInput',
              message: '请输入正确的座机号',
              pattern: '^(?:(?:\\d{3}-)?\\d{8}|^(?:\\d{4}-)?\\d{7,8})(?:-\\d+)?$',
              whitespace: true
            }
          ],
          'x-decorator': 'FormItem',
          'x-component': 'Input',
          'x-component-props': {
            placeholder: '请输入'
          }
        }
      }
    ]
  },
  {
    icon: 'TextAreaSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          type: 'string',
          title: '报审说明',
          name: 'reportingInstructions',
          'x-decorator': 'FormItem',
          'x-component': 'Input.TextArea',
          'x-component-props': {
            maxLength: 200,
            placeholder: '请输入'
          }
        }
      }
    ]
  }
)
