import React from 'react'
import { Select as FormilySelect } from '@formily/antd'
import { createBehavior, createResource } from '@designable/core'
import { DnFC } from '@designable/react'
import { createFieldSchema } from '../Field'
import { AllSchemas } from '../../schemas'
import { AllLocales } from '../../locales'

export const Select: DnFC<React.ComponentProps<typeof FormilySelect>> = FormilySelect

Select.Behavior = createBehavior(
  {
    name: 'Select',
    extends: ['Field'],
    selector: node => node.props['name'] === 'projectType',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Select)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Select['zh-CN'], title: '项目类型' } }
  },
  {
    name: 'Select',
    extends: ['Field'],
    selector: node => node.props['name'] === 'bScaleUnit',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Select)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Select['zh-CN'], title: '建设规模(单位)' } }
  },
  {
    name: 'Select',
    extends: ['Field'],
    selector: node => node.props['name'] === 'gcType',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Select)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Select['zh-CN'], title: '工程类型' } }
  },
  {
    name: 'Select',
    extends: ['Field'],
    selector: node => node.props['name'] === 'structureType',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Select)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Select['zh-CN'], title: '结构类型' } }
  },
  {
    name: 'Select',
    extends: ['Field'],
    selector: node => node.props['name'] === 'expendType',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Select)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Select['zh-CN'], title: '项目支出类别' } }
  },
  {
    name: 'Select',
    extends: ['Field'],
    selector: node => node.props['name'] === 'ysbzCompany',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Select)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Select['zh-CN'], title: '预算编制单位' } }
  },
  {
    name: 'Select',
    extends: ['Field'],
    selector: node => node.props['name'] === 'institutionID',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Select)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Select['zh-CN'], title: '建设单位' } }
  },
  {
    name: 'Select',
    extends: ['Field'],
    selector: node => node.props['name'] === 'reviewer',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Select)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Select['zh-CN'], title: '报审人' } }
  },
  {
    name: 'Select',
    extends: ['Field'],
    selector: node => node.props['name'] === 'projectContact',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Select)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Select['zh-CN'], title: '项目联系人' } }
  },
  {
    name: 'Select',
    extends: ['Field'],
    selector: node => node.props['name'] === 'area',
    designerProps: {
      propsSchema: createFieldSchema(AllSchemas.Select)
    },
    designerLocales: { 'zh-CN': { ...AllLocales.Select['zh-CN'], title: '所在区域' } }
  }
)

Select.Resource = createResource(
  {
    icon: 'SelectSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          title: '项目类型',
          name: 'projectType',
          required: true,
          'x-decorator': 'FormItem',
          'x-component': 'Select',
          'x-component-props': {
            placeholder: '请选择'
          }
        }
      }
    ]
  },
  {
    icon: 'SelectSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          title: '',
          name: 'bScaleUnit',
          required: true,
          'x-decorator': 'FormItem',
          'x-component': 'Select',
          'x-component-props': {
            placeholder: '请选择单位'
          }
        }
      }
    ]
  },
  {
    icon: 'SelectSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          title: '工程类型',
          name: 'gcType',
          'x-decorator': 'FormItem',
          'x-component': 'Select',
          'x-component-props': {
            placeholder: '请选择'
          }
        }
      }
    ]
  },

  {
    icon: 'SelectSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          title: '结构类型',
          name: 'structureType',
          'x-decorator': 'FormItem',
          'x-component': 'Select',
          'x-component-props': {
            placeholder: '请选择'
          }
        }
      }
    ]
  },
  {
    icon: 'SelectSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          title: '项目支出类别',
          name: 'expendType',
          required: true,
          'x-decorator': 'FormItem',
          'x-component': 'Select',
          'x-component-props': {
            placeholder: '请选择'
          }
        }
      }
    ]
  },
  {
    icon: 'SelectSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          title: '预算编制单位(全称)',
          name: 'ysbzCompany',
          required: true,
          'x-decorator': 'FormItem',
          'x-component': 'Select',
          'x-component-props': {
            placeholder: '请选择'
          }
        }
      }
    ]
  },
  {
    icon: 'SelectSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          title: '建设单位',
          name: 'institutionID',
          required: true,
          'x-decorator': 'FormItem',
          'x-component': 'Select',
          'x-component-props': {
            placeholder: '请选择'
          }
        }
      }
    ]
  },
  {
    icon: 'SelectSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          title: '报审人',
          name: 'reviewer',
          required: true,
          'x-decorator': 'FormItem',
          'x-component': 'Select',
          'x-component-props': {
            placeholder: '请选择'
          }
        }
      }
    ]
  },
  {
    icon: 'SelectSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          title: '项目联系人',
          name: 'projectContact',
          required: true,
          'x-decorator': 'FormItem',
          'x-component': 'Select',
          'x-component-props': {
            placeholder: '请选择'
          }
        }
      }
    ]
  },
  {
    icon: 'SelectSource',
    elements: [
      {
        componentName: 'Field',
        props: {
          title: '所在区域',
          name: 'area',
          required: true,
          'x-decorator': 'FormItem',
          'x-component': 'Select',
          'x-component-props': {
            placeholder: '请选择'
          }
        }
      }
    ]
  }
)
